@@ -2,22 +2,36 @@
 Compatibility tools for differences between Python 2 and 3
 """
 import sys
+from typing import TYPE_CHECKING
 
-PY37 = (sys.version_info[:2] == (3, 7))
+PY37 = sys.version_info[:2] == (3, 7)
 
 asunicode = lambda x, _: str(x)  # noqa:E731
 
 
+__all__ = [
+    "asunicode",
+    "asstr",
+    "asbytes",
+    "Literal",
+    "lmap",
+    "lzip",
+    "lrange",
+    "lfilter",
+    "with_metaclass",
+]
+
+
 def asbytes(s):
     if isinstance(s, bytes):
         return s
-    return s.encode('latin1')
+    return s.encode("latin1")
 
 
 def asstr(s):
     if isinstance(s, str):
         return s
-    return s.decode('latin1')
+    return s.decode("latin1")
 
 
 # list-producing versions of the major Python iterating functions
@@ -37,32 +51,6 @@ def lfilter(*args, **kwargs):
     return list(filter(*args, **kwargs))
 
 
-def iteritems(obj, **kwargs):
-    """replacement for six's iteritems for Python2/3 compat
-       uses 'iteritems' if available and otherwise uses 'items'.
-
-       Passes kwargs to method.
-    """
-    func = getattr(obj, "iteritems", None)
-    if not func:
-        func = obj.items
-    return func(**kwargs)
-
-
-def iterkeys(obj, **kwargs):
-    func = getattr(obj, "iterkeys", None)
-    if not func:
-        func = obj.keys
-    return func(**kwargs)
-
-
-def itervalues(obj, **kwargs):
-    func = getattr(obj, "itervalues", None)
-    if not func:
-        func = obj.values
-    return func(**kwargs)
-
-
 def with_metaclass(meta, *bases):
     """Create a base class with a metaclass."""
     # This requires a bit of explanation: the basic idea is to make a dummy
@@ -71,4 +59,13 @@ def with_metaclass(meta, *bases):
     class metaclass(meta):
         def __new__(cls, name, this_bases, d):
             return meta(name, bases, d)
-    return type.__new__(metaclass, 'temporary_class', (), {})
+
+    return type.__new__(metaclass, "temporary_class", (), {})
+
+
+if sys.version_info >= (3, 8):
+    from typing import Literal
+elif TYPE_CHECKING:
+    from typing_extensions import Literal
+else:
+    from typing import Any as Literal
