@@ -190,7 +190,7 @@ class TestProbPlotLongelyNoFit(BaseProbplotMixin):
 class TestProbPlotLongelyWithFit(BaseProbplotMixin):
     def setup(self):
         np.random.seed(5)
-        self.data = sm.datasets.longley.load(as_pandas=False)
+        self.data = sm.datasets.longley.load()
         self.data.exog = sm.add_constant(self.data.exog, prepend=False)
         self.mod_fit = sm.OLS(self.data.endog, self.data.exog).fit()
         self.prbplt = ProbPlot(
@@ -288,7 +288,7 @@ class TestProbPlotRandomNormalLocScaleDist(BaseProbplotMixin):
 
 class TestTopLevel:
     def setup(self):
-        self.data = sm.datasets.longley.load(as_pandas=False)
+        self.data = sm.datasets.longley.load()
         self.data.exog = sm.add_constant(self.data.exog, prepend=False)
         self.mod_fit = sm.OLS(self.data.endog, self.data.exog).fit()
         self.res = self.mod_fit.resid
@@ -329,7 +329,7 @@ class TestTopLevel:
 def test_invalid_dist_config(close_figures):
     # GH 4226
     np.random.seed(5)
-    data = sm.datasets.longley.load(as_pandas=False)
+    data = sm.datasets.longley.load()
     data.exog = sm.add_constant(data.exog, prepend=False)
     mod_fit = sm.OLS(data.endog, data.exog).fit()
     with pytest.raises(TypeError, match=r"dist\(0, 1, 4, loc=0, scale=1\)"):
@@ -423,19 +423,31 @@ class TestDoPlot:
     @pytest.mark.matplotlib
     def test_plot_full_options(self, close_figures):
         gofplots._do_plot(
-            self.x, self.y, ax=self.ax, step=False, **self.full_options,
+            self.x,
+            self.y,
+            ax=self.ax,
+            step=False,
+            **self.full_options,
         )
 
     @pytest.mark.matplotlib
     def test_step_baseline(self, close_figures):
         gofplots._do_plot(
-            self.x, self.y, ax=self.ax, step=True, **self.step_options,
+            self.x,
+            self.y,
+            ax=self.ax,
+            step=True,
+            **self.step_options,
         )
 
     @pytest.mark.matplotlib
     def test_step_full_options(self, close_figures):
         gofplots._do_plot(
-            self.x, self.y, ax=self.ax, step=True, **self.full_options,
+            self.x,
+            self.y,
+            ax=self.ax,
+            step=True,
+            **self.full_options,
         )
 
     @pytest.mark.matplotlib
@@ -616,3 +628,61 @@ def test_param_unpacking():
     assert_equal(pp.fit_params, expected)
     pp = ProbPlot(np.empty(100), stats.beta(a=2, b=3, loc=4, scale=5))
     assert_equal(pp.fit_params, expected)
+
+
+@pytest.mark.matplotlib
+@pytest.mark.parametrize("labels", [{}, {"xlabel": "X", "ylabel": "Y"}])
+@pytest.mark.parametrize("x_size", [30, 50])
+@pytest.mark.parametrize("y_size", [30, 50])
+@pytest.mark.parametrize("line", [None, "45", "s", "r", "q"])
+def test_correct_labels(
+    close_figures, reset_randomstate, line, x_size, y_size, labels
+):
+    rs = np.random.RandomState(9876554)
+    x = rs.normal(loc=0, scale=0.1, size=x_size)
+    y = rs.standard_t(3, size=y_size)
+    pp_x = sm.ProbPlot(x)
+    pp_y = sm.ProbPlot(y)
+    fig = qqplot_2samples(pp_x, pp_y, line=line, **labels)
+    ax = fig.get_axes()[0]
+    x_label = ax.get_xlabel()
+    y_label = ax.get_ylabel()
+    if x_size < y_size:
+        if not labels:
+            assert "2nd" in x_label
+            assert "1st" in y_label
+        else:
+            assert "Y" in x_label
+            assert "X" in y_label
+    else:
+        if not labels:
+            assert "1st" in x_label
+            assert "2nd" in y_label
+        else:
+            assert "X" in x_label
+            assert "Y" in y_label
+
+
+@pytest.mark.matplotlib
+def test_axis_order(close_figures):
+    xx = np.random.normal(10, 1, (100,))
+    xy = np.random.normal(1, 0.01, (100,))
+    fig = qqplot_2samples(xx, xy, "x", "y")
+    ax = fig.get_axes()[0]
+    y_range = np.diff(ax.get_ylim())[0]
+    x_range = np.diff(ax.get_xlim())[0]
+    assert y_range < x_range
+
+    xx_long = np.random.normal(10, 1, (1000,))
+    fig = qqplot_2samples(xx_long, xy, "x", "y")
+    ax = fig.get_axes()[0]
+    y_range = np.diff(ax.get_ylim())[0]
+    x_range = np.diff(ax.get_xlim())[0]
+    assert y_range < x_range
+
+    xy_long = np.random.normal(1, 0.01, (1000,))
+    fig = qqplot_2samples(xx, xy_long, "x", "y")
+    ax = fig.get_axes()[0]
+    y_range = np.diff(ax.get_ylim())[0]
+    x_range = np.diff(ax.get_xlim())[0]
+    assert x_range < y_range
