@@ -462,7 +462,7 @@ class ThetaModelResults:
         if self.model.deseasonalize:
             seasonal = self._seasonal
             period = self.model.period
-            oos_idx = nobs + np.arange(1, steps + 1)
+            oos_idx = nobs + np.arange(steps)
             seasonal_locs = oos_idx % period
             if seasonal.shape[0]:
                 season[:] = seasonal[seasonal_locs]
@@ -646,7 +646,7 @@ class ThetaModelResults:
 
         ax = fig.add_subplot(111)
         nobs = self.model.endog_orig.shape[0]
-        index = pd.Int64Index(np.arange(nobs))
+        index = pd.Index(np.arange(nobs))
         if in_sample:
             if isinstance(self.model.endog_orig, pd.Series):
                 index = self.model.endog_orig.index
