@@ -4,7 +4,6 @@ Tests for the generic MLEModel
 Author: Chad Fulton
 License: Simplified-BSD
 """
-
 import os
 import re
 import warnings
@@ -18,7 +17,7 @@ from statsmodels.tsa.statespace import (sarimax, varmax, kalman_filter,
 from statsmodels.tsa.statespace.mlemodel import MLEModel, MLEResultsWrapper
 from statsmodels.datasets import nile
 from numpy.testing import (
-    assert_almost_equal, assert_equal, assert_allclose, assert_raises)
+    assert_, assert_almost_equal, assert_equal, assert_allclose, assert_raises)
 from statsmodels.tsa.statespace.tests.results import (
     results_sarimax, results_var_misc)
 
@@ -844,9 +843,29 @@ def test_diagnostics():
         res.test_serial_correlation(method='invalid')
 
     # Smoke tests for other options
-    actual = res.test_heteroskedasticity(method=None, alternative='d',
-                                         use_f=False)
-    desired = res.test_serial_correlation(method='boxpierce')
+    res.test_heteroskedasticity(method=None, alternative='d', use_f=False)
+    res.test_serial_correlation(method='boxpierce')
+
+
+def test_small_sample_serial_correlation_test():
+    # Test the Ljung Box serial correlation test for small samples with df
+    # adjustment using the Nile dataset. Ljung-Box statistic and p-value
+    # are compared to R's Arima() and checkresiduals() functions in forecast
+    # package:
+    # library(forecast)
+    # fit <- Arima(y, order=c(1,0,1), include.constant=FALSE)
+    # checkresiduals(fit, lag=10)
+    from statsmodels.tsa.statespace.sarimax import SARIMAX
+    niledata = nile.data.load_pandas().data
+    niledata.index = pd.date_range('1871-01-01', '1970-01-01', freq='AS')
+    mod = SARIMAX(
+        endog=niledata['volume'], order=(1, 0, 1), trend='n',
+        freq=niledata.index.freq)
+    res = mod.fit()
+
+    actual = res.test_serial_correlation(
+        method='ljungbox', lags=10, df_adjust=True)[0, :, -1]
+    assert_allclose(actual, [14.116, 0.0788], atol=1e-3)
 
 
 def test_diagnostics_nile_eviews():
@@ -1108,3 +1127,101 @@ def test_integer_params():
     res = mod.filter([1, 0])
     p = res.predict(end=5, dynamic=True, exog=[3, 3, 4])
     assert_equal(p.dtype, np.float64)
+
+
+def check_states_index(states, ix, predicted_ix, cols):
+    predicted_cov_ix = pd.MultiIndex.from_product(
+        [predicted_ix, cols]).swaplevel()
+    filtered_cov_ix = pd.MultiIndex.from_product([ix, cols]).swaplevel()
+    smoothed_cov_ix = pd.MultiIndex.from_product([ix, cols]).swaplevel()
+
+    # Predicted
+    assert_(states.predicted.index.equals(predicted_ix))
+    assert_(states.predicted.columns.equals(cols))
+
+    assert_(states.predicted_cov.index.equals(predicted_cov_ix))
+    assert_(states.predicted.columns.equals(cols))
+
+    # Filtered
+    assert_(states.filtered.index.equals(ix))
+    assert_(states.filtered.columns.equals(cols))
+
+    assert_(states.filtered_cov.index.equals(filtered_cov_ix))
+    assert_(states.filtered.columns.equals(cols))
+
+    # Smoothed
+    assert_(states.smoothed.index.equals(ix))
+    assert_(states.smoothed.columns.equals(cols))
+
+    assert_(states.smoothed_cov.index.equals(smoothed_cov_ix))
+    assert_(states.smoothed.columns.equals(cols))
+
+
+def test_states_index_periodindex():
+    nobs = 10
+    ix = pd.period_range(start='2000', periods=nobs, freq='M')
+    endog = pd.Series(np.zeros(nobs), index=ix)
+
+    mod = sarimax.SARIMAX(endog, order=(2, 0, 0))
+    res = mod.smooth([0.5, 0.1, 1.0])
+
+    predicted_ix = pd.period_range(start=ix[0], periods=nobs + 1, freq='M')
+    cols = pd.Index(['state.0', 'state.1'])
+
+    check_states_index(res.states, ix, predicted_ix, cols)
+
+
+def test_states_index_dateindex():
+    nobs = 10
+    ix = pd.date_range(start='2000', periods=nobs, freq='M')
+    endog = pd.Series(np.zeros(nobs), index=ix)
+
+    mod = sarimax.SARIMAX(endog, order=(2, 0, 0))
+    res = mod.smooth([0.5, 0.1, 1.0])
+
+    predicted_ix = pd.date_range(start=ix[0], periods=nobs + 1, freq='M')
+    cols = pd.Index(['state.0', 'state.1'])
+
+    check_states_index(res.states, ix, predicted_ix, cols)
+
+
+def test_states_index_int64index():
+    nobs = 10
+    ix = pd.Index(np.arange(10))
+    endog = pd.Series(np.zeros(nobs), index=ix)
+
+    mod = sarimax.SARIMAX(endog, order=(2, 0, 0))
+    res = mod.smooth([0.5, 0.1, 1.0])
+
+    predicted_ix = pd.Index(np.arange(11))
+    cols = pd.Index(['state.0', 'state.1'])
+
+    check_states_index(res.states, ix, predicted_ix, cols)
+
+
+def test_states_index_rangeindex():
+    nobs = 10
+
+    # Basic range index
+    ix = pd.RangeIndex(10)
+    endog = pd.Series(np.zeros(nobs), index=ix)
+
+    mod = sarimax.SARIMAX(endog, order=(2, 0, 0))
+    res = mod.smooth([0.5, 0.1, 1.0])
+
+    predicted_ix = pd.RangeIndex(11)
+    cols = pd.Index(['state.0', 'state.1'])
+
+    check_states_index(res.states, ix, predicted_ix, cols)
+
+    # More complex range index
+    ix = pd.RangeIndex(2, 32, 3)
+    endog = pd.Series(np.zeros(nobs), index=ix)
+
+    mod = sarimax.SARIMAX(endog, order=(2, 0, 0))
+    res = mod.smooth([0.5, 0.1, 1.0])
+
+    predicted_ix = pd.RangeIndex(2, 35, 3)
+    cols = pd.Index(['state.0', 'state.1'])
+
+    check_states_index(res.states, ix, predicted_ix, cols)
